==> vulnmine-1.0.3.tar.gz: vulnmine-1.0.3/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='vulnmine',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='1.0.3',

    description='Mine SCCM and NIST NVD for host vulnerability data',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/lorgor/vulnmine',

    # Author details
    author='Loren Gordon',
    author_email='lgordon@lgsec.biz',

    # Choose your license
    license='GPLv3',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 2 - Pre-Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Information Technology',
        'Topic :: Security',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        #'Programming Language :: Python :: 3',
        #'Programming Language :: Python :: 3.4',
        #'Programming Language :: Python :: 3.5',
        #'Programming Language :: Python :: 3.6',
    ],

    # What does your project relate to?
    keywords='machine learning data mining vulnerability',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
                'fuzzywuzzy',
                'numpy',
                'pandas',
                'python-Levenshtein',
                'python-dev',
                'scikit-learn==0.18.2',
                'sympy',
                'scipy==0.19.1',
                'schedule',
                'xmltodict',
                'yapsy'
                ],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
        'dev': ['check-manifest'],
        'test': [
                'coverage',
                'pytest',
                'requests',
                'responses'
                ],
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
       'vulnmine': [
                'tests/data/*',
                'tests/conf*.py',
                'tests/rebuild*.py',
                'plugins/*.py'
                ],
       },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    data_files=[('data', [
                        'data/conf/logging.json',
                        'data/csv/label_software.csv',
                        'data/csv/label_vendors.csv',
                        'data/csv/s_vndr_stop_wds.csv',
                        'data/models/software_classif_trained_Rdm_Forest.pkl.z',
                        'data/models/vendor_classif_trained_Rdm_Forest.pkl.z'
                        ])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
)

==> vulnmine-1.0.4.tar.gz: vulnmine-1.0.4/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='vulnmine',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='1.0.4',

    description='Mine SCCM and NIST NVD for host vulnerability data',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/lorgor/vulnmine',

    # Author details
    author='Loren Gordon',
    author_email='lgordon@lgsec.biz',

    # Choose your license
    license='GPLv3',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Information Technology',
        'Topic :: Security',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        #'Programming Language :: Python :: 3',
        #'Programming Language :: Python :: 3.4',
        #'Programming Language :: Python :: 3.5',
        #'Programming Language :: Python :: 3.6',
    ],

    # What does your project relate to?
    keywords='machine learning data mining vulnerability',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
                'fuzzywuzzy',
                'numpy',
                'pandas',
                'python-Levenshtein',
                'requests',
                'scikit-learn==0.18.2',
                'sympy',
                'scipy==0.19.1',
                'schedule',
                'xmltodict',
                'yapsy'
                ],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
        'dev': ['check-manifest'],
        'test': [
                'coverage',
                'pytest',
                'requests',
                'responses'
                ],
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
       'vulnmine': [
                'plugins/*',
                'vulnmine_data/*'                ],
       },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-
    # additional-files # noqa In this case, 'data_file' will be installed into
    # '<sys.prefix>/my_data'

    # data_files=[('vulnmine_data', [
    #         'data/vulnmine_data/logging.json',
    #         'data/vulnmine_data/vulnmine_defaults.ini',
    #         'data/vulnmine_data/label_software.csv',
    #         'data/vulnmine_data/label_vendors.csv',
    #         'data/vulnmine_data/s_vndr_stop_wds.csv',
    #         'data/vulnmine_data/software_classif_trained_Rdm_Forest.pkl.z',
    #         'data/vulnmine_data/vendor_classif_trained_Rdm_Forest.pkl.z'
    #         ])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
)
